/*
 * Syncdaemon API
 *
 * Authors: Rodrigo Moya <rodrigo.moya@canonical.com>
 *
 * Copyright 2010 Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 3, as published
 * by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranties of
 * MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef __SYNCDAEMON_DAEMON_H__
#define __SYNCDAEMON_DAEMON_H__

#include <glib-object.h>
#include "syncdaemon-interface.h"

G_BEGIN_DECLS

#define SYNCDAEMON_TYPE_DAEMON                (syncdaemon_daemon_get_type ())
#define SYNCDAEMON_DAEMON(obj)                (G_TYPE_CHECK_INSTANCE_CAST ((obj), SYNCDAEMON_TYPE_DAEMON, SyncdaemonDaemon))
#define SYNCDAEMON_IS_DAEMON(obj)             (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SYNCDAEMON_TYPE_DAEMON))
#define SYNCDAEMON_DAEMON_CLASS(klass)        (G_TYPE_CHECK_CLASS_CAST ((klass), SYNCDAEMON_TYPE_DAEMON, SyncdaemonDaemonClass))
#define SYNCDAEMON_IS_DAEMON_CLASS(klass)     (G_TYPE_CHECK_CLASS_TYPE ((klass), SYNCDAEMON_TYPE_DAEMON))
#define SYNCDAEMON_DAEMON_GET_CLASS(obj)      (G_TYPE_INSTANCE_GET_CLASS ((obj), SYNCDAEMON_TYPE_DAEMON, SyncdaemonDaemonClass))

typedef struct _SyncdaemonDaemonPrivate SyncdaemonDaemonPrivate;

typedef struct {
	GObject parent;
	SyncdaemonDaemonPrivate *priv;
} SyncdaemonDaemon;

typedef struct {
	GObjectClass parent_class;

	/* Signals */
	void (* connected) (SyncdaemonDaemon *daemon);
	void (* disconnected) (SyncdaemonDaemon *daemon);

	void (* event) (SyncdaemonDaemon *daemon, GHashTable *event_dict);
	void (* error) (SyncdaemonDaemon *daemon, const gchar *signal, GHashTable *extra_args);
} SyncdaemonDaemonClass;

GType                syncdaemon_daemon_get_type (void);

SyncdaemonDaemon    *syncdaemon_daemon_new (void);
gboolean             syncdaemon_daemon_connect (SyncdaemonDaemon *daemon);
gboolean             syncdaemon_daemon_disconnect (SyncdaemonDaemon *daemon);
gboolean             syncdaemon_daemon_quit (SyncdaemonDaemon *daemon);
const gchar         *syncdaemon_daemon_get_root_dir (SyncdaemonDaemon *daemon);

SyncdaemonInterface *syncdaemon_daemon_get_config_interface (SyncdaemonDaemon *daemon);
SyncdaemonInterface *syncdaemon_daemon_get_events_interface (SyncdaemonDaemon *daemon);
SyncdaemonInterface *syncdaemon_daemon_get_status_interface (SyncdaemonDaemon *daemon);

G_END_DECLS

#endif
